@@ -1,21 +1,20 @@
 #!/usr/bin/env python
 #
 # Semaphore: A simple (rule-based) bot library for Signal Private Messenger.
-# Copyright (C) 2020
-# Lazlo Westerhof <semaphore@lazlo.me>
+# Copyright (C) 2020 Lazlo Westerhof <semaphore@lazlo.me>
 #
 # This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# it under the terms of the GNU Affero General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Lesser Public License for more details.
+# GNU Affero General Public License for more details.
 #
-# You should have received a copy of the GNU Lesser Public License
-# along with this program.  If not, see [http://www.gnu.org/licenses/].
+# You should have received a copy of the GNU Affero General Public License
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """This module contains an object that represents a Signal message."""
 from typing import Optional, TYPE_CHECKING
 
@@ -66,6 +65,10 @@ class Message:
         else:
             return self.data_message.body
 
+    def get_sticker(self):
+        """Return the message's sticker if there is one."""
+        return self.data_message.sticker
+
     def get_group_id(self) -> Optional[str]:
         """Get group id if message is a group message."""
         if self.data_message and self.data_message.group:
@@ -73,17 +76,17 @@ class Message:
         else:
             return None
 
-    def reply(self, *args, **kwargs) -> None:
+    async def reply(self, *args, **kwargs) -> None:
         """Send a reply to the message.
 
         The args are the same as for the Reply constructor.
         """
-        self._sender.send_message(self, Reply(*args, **kwargs))
+        await self._sender.send_message(self, Reply(*args, **kwargs))
 
-    def mark_delivered(self) -> None:
+    async def mark_delivered(self) -> None:
         """Mark the message as delivered."""
-        self._sender.mark_delivered(self)
+        await self._sender.mark_delivered(self)
 
-    def mark_read(self) -> None:
+    async def mark_read(self) -> None:
         """Mark the message as read."""
-        self._sender.mark_read(self)
+        await self._sender.mark_read(self)
